=========================
Sample Configuration File
=========================

The following is a sample Ironic configuration for adaptation and use. For a
detailed overview of all available configuration options, refer to
:doc:`config`.

The sample configuration can also be viewed in :download:`file form
</_static/ironic.conf.sample>`.

.. important::

   The sample configuration file is auto-generated from Ironic when this
   documentation is built. You must ensure your version of Ironic matches the
   version of this documentation.

.. literalinclude:: /_static/ironic.conf.sample
